@@ -18,19 +18,28 @@ class Gitiles(object):
         if config is None or config.get('gitiles', None) is None:
             raise GitilesException('config invalid')
         self._pass = config['gitiles'].get('pass', '')
-        self._url = config['gitiles'].get('host', 'localhost').rstrip('/') + ':' + str(config['gitiles'].get('port', 80)) + '/a'
+        self._url = config['gitiles'].get('url', 'http://localhost:80').rstrip('/')
         self._user = config['gitiles'].get('user', '')
 
     def commit(self, repo, commit):
-        response = requests.get(url=self._url + '/plugins/gitiles/%s/+/%s?format=JSON' % (repo, commit),
-                                auth=(self._user, self._pass))
+        if len(self._pass) == 0 or len(self._user) == 0:
+            response = requests.get(url=self._url + '/%s/+/%s?format=JSON' % (repo, commit))
+        else:
+            response = requests.get(url=self._url + '/%s/+/%s?format=JSON' % (repo, commit),
+                                    auth=(self._user, self._pass))
         if response.status_code != requests.codes.ok:
             return None
         return json.loads(response.text.replace(")]}'", ''))
 
     def commits(self, repo, branch, commit):
-        response = requests.get(url=self._url + '/plugins/gitiles/%s/+log/%s/?s=%s&format=JSON' % (repo, branch, commit),
-                                auth=(self._user, self._pass))
+        if len(self._pass) == 0 or len(self._user) == 0:
+            response = requests.get(url=self._url + '/%s/+log/%s/?s=%s&format=JSON' % (repo, branch, commit))
+        else:
+            response = requests.get(url=self._url + '/%s/+log/%s/?s=%s&format=JSON' % (repo, branch, commit),
+                                    auth=(self._user, self._pass))
         if response.status_code != requests.codes.ok:
             return None
         return json.loads(response.text.replace(")]}'", ''))
+
+    def url(self):
+        return self._url
